@@ -93,8 +93,7 @@ class _Deployment(APIGroup):
             raise
 
         if print_warning:
-            # credentials are stored in the list, but it contains one item.
-            new_conf = deployment.spec
+            new_conf = deployment.env_obj.spec
             LOG.warning(
                 "The used config schema is deprecated since Rally 0.10.0. "
                 "The new one is much simpler, try it now:\n%s"
@@ -138,16 +137,6 @@ class _Deployment(APIGroup):
     def get(self, deployment):
         return self._get(deployment).to_dict()
 
-    def service_list(self, deployment):
-        """Get the services list.
-
-        :param deployment: Deployment object
-        :returns: Service list
-        """
-        # TODO(astudenov): make this method platform independent
-        admin = deployment.get_credentials_for("openstack")["admin"]
-        return admin.list_services()
-
     def list(self, status=None, parent_uuid=None, name=None):
         """Get the deployments list.
 
